summaryrefslogtreecommitdiffstats
path: root/kturtle/src/canvas.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kturtle/src/canvas.cpp')
-rw-r--r--kturtle/src/canvas.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kturtle/src/canvas.cpp b/kturtle/src/canvas.cpp
index 38281956..e21ad4ea 100644
--- a/kturtle/src/canvas.cpp
+++ b/kturtle/src/canvas.cpp
@@ -18,7 +18,7 @@
// Note on this file:
// It contains 200 lines of code just to make sure very long line are drawn correctly
// till a certain extent... Beyond that extent the code just cuts the crap, since use user
// it then probably not doing anything usefull anymore; so he she will not notice the code
// is cheating a bit in order to prevent CPU hogging.
@@ -75,10 +75,10 @@ const double DEG2RAD = 3.14159265358979323846/180;
// BEGIN public methods
-Canvas::Canvas(TQWidget *parent, const char *name) : TQCanvasView(0, parent, name)
+Canvas::Canvas(TQWidget *tqparent, const char *name) : TQCanvasView(0, tqparent, name)
{
// Create a new canvas for this view
- canvas = new TQCanvas(parent);
+ canvas = new TQCanvas(TQT_TQOBJECT(tqparent));
canvas->setAdvancePeriod(250); // refresh-rate in [ms]
// set initial values
@@ -297,11 +297,11 @@ void Canvas::slotPrint(TQString text)
void Canvas::slotFontType(TQString family, TQString extra)
{
font.setFamily(family);
- font.setBold( extra.contains("bold") > 0 );
- font.setItalic( extra.contains("italic") > 0 );
- font.setUnderline( extra.contains("underline") > 0 );
- font.setOverline( extra.contains("overline") > 0 );
- font.setStrikeOut( extra.contains("strikeout") > 0 );
+ font.setBold( extra.tqcontains("bold") > 0 );
+ font.setItalic( extra.tqcontains("italic") > 0 );
+ font.setUnderline( extra.tqcontains("underline") > 0 );
+ font.setOverline( extra.tqcontains("overline") > 0 );
+ font.setStrikeOut( extra.tqcontains("strikeout") > 0 );
}
void Canvas::slotFontSize(int px)
@@ -18,7 +18,7 @@
// Note on this file:
-// It contains 200 lines of code just to make sure very long line are drawn correctly
+// It tqcontains 200 lines of code just to make sure very long line are drawn correctly
// till a certain extent... Beyond that extent the code just cuts the crap, since use user
// it then probably not doing anything usefull anymore; so he she will not notice the code